<template>
  <i v-if="isShowIconSvg" class="el-icon" :style="setIconSvgStyle">
    <component :is="getIconName" />
  </i>
  <div v-else-if="isShowIconImg" :style="setIconImgOutStyle">
    <img :src="getIconName" :style="setIconSvgInsStyle" />
  </div>
  <i v-else :class="getIconName" :style="setIconSvgStyle" />
</template>

<script setup lang="ts" name="svgIcon">
import { computed, toRefs } from 'vue'
const props = defineProps({
  name: {// svg 图标组件名字
    type: String
  },
  size: {// svg 大小
    type: Number,
    default: () => 14
  },
  color: {	// svg 颜色
    type: String
  }
})
const { name, size, color } = toRefs(props)
// 在线链接、本地引入地址前缀
const linesString = ['https', 'http', '/src', '/assets', 'data:image', import.meta.env.VITE_PUBLIC_PATH]
// 获取 icon 图标名称
const getIconName = computed(() => {
  return name?.value
})
// 用于判断 element plus 自带 svg 图标的显示、隐藏
const isShowIconSvg = computed(() => {
  return name?.value?.startsWith('ele-')
})
// 用于判断在线链接、本地引入等图标显示、隐藏
const isShowIconImg = computed(() => {
  return linesString.find((str) => name?.value?.startsWith(str))//startsWith() 如果字符串是以指定的子字符串开头返回 true，否则 false。
})
// 设置图标样式
const setIconSvgStyle = computed(() => {
  return `font-size:${size.value}px;color:${color?.value}` //color与color.value  555
})
// 设置图片样式
const setIconImgOutStyle = computed(() => {
  return `width:${size.value}px;height:${size.value}px;display:inline-block;overflow:hidden`
})
// 设置图片样式
const setIconSvgInsStyle = computed(() => {
  const filterStyle: string[] = []
  const compatibles: string[] = ['-webkit', '-ms', '-o', '-moz']
  compatibles.forEach((j) => filterStyle.push(`${j}-filter:drop-shadow(${color?.value} 30px 0)`))
  return `width:${size.value}px;height:${size.value}px;position:relative;left:-${size.value}px;${filterStyle.join('')}`
})


</script>
<style lang='scss' scoped></style>